OC.L10N.register(
    "core",
    {
    "Please select a file." : "Please select a file.",
    "File is too big" : "File is too big",
    "The selected file is not an image." : "The selected file is not an image.",
    "The selected file cannot be read." : "The selected file cannot be read.",
    "Invalid file provided" : "Invalid file provided",
    "No image or file provided" : "No image or file provided",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "An error occurred. Please contact your admin." : "An error occurred. Please contact your admin.",
    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
    "No crop data provided" : "No crop data provided",
    "No valid crop data provided" : "No valid crop data provided",
    "Crop is not square" : "Crop is not square",
    "State token does not match" : "State token does not match",
    "Password reset is disabled" : "Password reset is disabled",
    "Couldn't reset password because the token is invalid" : "Couldn't reset password because the token is invalid",
    "Couldn't reset password because the token is expired" : "Couldn't reset password because the token is expired",
    "%s password reset" : "%s password reset",
    "Password reset" : "Password reset",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
    "Reset your password" : "Reset your password",
    "Preparing update" : "Preparing update",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Checking table %s",
    "Turned on maintenance mode" : "Turned on maintenance mode",
    "Turned off maintenance mode" : "Turned off maintenance mode",
    "Maintenance mode is kept active" : "Maintenance mode is kept active",
    "Updating database schema" : "Updating database schema",
    "Updated database" : "Updated database",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema can be updated (this can take a long time depending on the database size)",
    "Checked database schema update" : "Checked database schema update",
    "Checking updates of apps" : "Checking updates of apps",
    "Checking for update of app \"%s\" in appstore" : "Checking for update of app \"%s\" in appstore",
    "Update app \"%s\" from appstore" : "Update app \"%s\" from appstore",
    "Checked for update of app \"%s\" in appstore" : "Checked for update of app \"%s\" in appstore",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)",
    "Checked database schema update for apps" : "Checked database schema update for apps",
    "Set log level to debug" : "Set log level to debug",
    "Reset log level" : "Reset log level",
    "Starting code integrity check" : "Starting code integrity check",
    "Finished code integrity check" : "Finished code integrity check",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Following apps have been disabled: %s",
    "Already up to date" : "Already up to date",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Your web server is not yet properly set up to allow file synchronisation, because the WebDAV interface seems to be broken.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Missing index \"{indexName}\" in table \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
    "restricted" : "restricted",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Delete",
    "Rename" : "Rename",
    "Collaborative tags" : "Collaborative tags",
    "No tags found" : "No tags found",
    "unknown text" : "unknown text",
    "Hello world!" : "Hello world!",
    "sunny" : "sunny",
    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
    "Hello {name}" : "Hello {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
    "new" : "new",
    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
    "Update to {version}" : "Update to {version}",
    "An error occurred." : "An error occurred.",
    "Please reload the page." : "Please reload the page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "Continue to Nextcloud" : "Continue to Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["The update was successful. Redirecting you to Nextcloud in %n second.","The update was successful. Redirecting you to Nextcloud in %n seconds."],
    "Searching other places" : "Searching other places",
    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} search result in another folder","{count} search results in other folders"],
    "Server side authentication failed!" : "Server side authentication failed!",
    "Please contact your administrator." : "Please contact your administrator.",
    "An internal error occurred." : "An internal error occurred.",
    "Please try again or contact your administrator." : "Please try again or contact your administrator.",
    "Username or email" : "Username or email",
    "Password" : "Password",
    "Log in" : "Log in",
    "Logging in …" : "Logging in …",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
    "Reset password" : "Reset password",
    "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
    "Password can not be changed. Please contact your administrator." : "Password can not be changed. Please contact your administrator.",
    "Back to login" : "Back to login",
    "New password" : "New password",
    "I know what I'm doing" : "I know what I'm doing",
    "Forgot password?" : "Forgot password?",
    "Settings" : "Settings",
    "Could not load your contacts" : "Could not load your contacts",
    "Search contacts …" : "Search contacts …",
    "No contacts found" : "No contacts found",
    "Show all contacts …" : "Show all contacts …",
    "Loading your contacts …" : "Loading your contacts …",
    "Looking for {term} …" : "Looking for {term} …",
    "No" : "No",
    "Yes" : "Yes",
    "No files in here" : "No files in here",
    "Choose" : "Choose",
    "Copy" : "Copy",
    "Move" : "Move",
    "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Error loading message template: {error}",
    "read-only" : "read-only",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file conflict","{count} file conflicts"],
    "One file conflict" : "One file conflict",
    "New Files" : "New Files",
    "Already existing files" : "Already existing files",
    "Which files do you want to keep?" : "Which files do you wish to keep?",
    "If you select both versions, the copied file will have a number added to its name." : "If you select both versions, the copied file will have a number added to its name.",
    "Cancel" : "Cancel",
    "Continue" : "Continue",
    "(all selected)" : "(all selected)",
    "({count} selected)" : "({count} selected)",
    "Error loading file exists template" : "Error loading file exists template",
    "Pending" : "Pending",
    "Copy to {folder}" : "Copy to {folder}",
    "Move to {folder}" : "Move to {folder}",
    "Saving..." : "Saving...",
    "Authentication required" : "Authentication required",
    "This action requires you to confirm your password" : "This action requires you to confirm your password",
    "Confirm" : "Confirm",
    "Failed to authenticate, try again" : "Failed to authenticate, try again",
    "seconds ago" : "seconds ago",
    "Connection to server lost" : "Connection to server lost",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
    "No action available" : "No action available",
    "Error fetching contact actions" : "Error fetching contact actions",
    "Personal" : "Personal",
    "Users" : "Users",
    "Apps" : "Apps",
    "Admin" : "Admin",
    "Help" : "Help",
    "Access forbidden" : "Access denied",
    "File not found" : "File not found",
    "Error" : "Error",
    "Internal Server Error" : "Internal Server Error",
    "The server was unable to complete your request." : "The server was unable to complete your request.",
    "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
    "More details can be found in the server log." : "More details can be found in the server log.",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Line: %s",
    "Trace" : "Trace",
    "Security warning" : "Security warning",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "Create an <strong>admin account</strong>" : "Create an <strong>admin account</strong>",
    "Username" : "Username",
    "Storage & database" : "Storage & database",
    "Data folder" : "Data folder",
    "Configure the database" : "Configure the database",
    "Only %s is available." : "Only %s is available.",
    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
    "For more details check out the documentation." : "For more details check out the documentation.",
    "Database user" : "Database user",
    "Database password" : "Database password",
    "Database name" : "Database name",
    "Database tablespace" : "Database tablespace",
    "Database host" : "Database host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
    "Performance warning" : "Performance warning",
    "Finish setup" : "Finish setup",
    "Finishing …" : "Finishing …",
    "Need help?" : "Need help?",
    "See the documentation" : "See the documentation",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
    "More apps" : "More apps",
    "More apps menu" : "More apps menu",
    "Search" : "Search",
    "Reset search" : "Reset search",
    "Contacts" : "Contacts",
    "Contacts menu" : "Contacts menu",
    "Settings menu" : "Settings menu",
    "Confirm your password" : "Confirm your password",
    "Connect to your account" : "Connect to your account",
    "App token" : "App token",
    "Grant access" : "Grant access",
    "Alternative log in using app token" : "Alternative log in using app token",
    "Account access" : "Account access",
    "Two-factor authentication" : "Two-factor authentication",
    "Use backup code" : "Use backup code",
    "Cancel log in" : "Cancel log in",
    "Error while validating your second factor" : "Error while validating your second factor",
    "Access through untrusted domain" : "Access through untrusted domain",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
    "App update required" : "App update required",
    "These apps will be updated:" : "These apps will be updated:",
    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
    "The theme %s has been disabled." : "The theme %s has been disabled.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
    "Start update" : "Start update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
    "Detailed logs" : "Detailed logs",
    "Update needed" : "Update needed",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Could not send reset email because there is no email address for this username. Please contact your administrator.",
    "Couldn't send reset email. Please make sure your username is correct." : "Couldn't send reset email. Please make sure your username is correct.",
    "Dismiss" : "Dismiss",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?",
    "Sending email …" : "Sending email …",
    "Shared" : "Shared",
    "Shared with" : "Shared with",
    "Shared by" : "Shared by",
    "Choose a password for the public link" : "Choose a password for the public link",
    "Choose a password for the public link or press the \"Enter\" key" : "Choose a password for the public link or press the \"Enter\" key",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "Resharing is not allowed" : "Resharing is not allowed",
    "Link" : "Link",
    "Password protect" : "Password protect",
    "Allow editing" : "Allow editing",
    "Email link to person" : "Email link to person",
    "Send" : "Send",
    "Allow upload and editing" : "Allow upload and editing",
    "Read only" : "Read only",
    "File drop (upload only)" : "File drop (upload only)",
    "Set expiration date" : "Set expiration date",
    "Expiration" : "Expiration",
    "Expiration date" : "Expiration date",
    "Unshare" : "Unshare",
    "Share to {name}" : "Share to {name}",
    "Share link" : "Share link",
    "Could not unshare" : "Could not unshare",
    "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
    "Shared with you by {owner}" : "Shared with you by {owner}",
    "Choose a password for the mail share" : "Choose a password for the mail share",
    "group" : "group",
    "remote" : "remote",
    "email" : "email",
    "shared by {sharer}" : "shared by {sharer}",
    "Can reshare" : "Can reshare",
    "Can edit" : "Can edit",
    "Can create" : "Can create",
    "Can change" : "Can change",
    "Can delete" : "Can delete",
    "Access control" : "Access control",
    "Error while sharing" : "Error whilst sharing",
    "Share details could not be loaded for this item." : "Share details could not be loaded for this item.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["At least {count} character is needed for autocompletion","At least {count} characters are needed for autocompletion"],
    "This list is maybe truncated - please refine your search term to see more results." : "This list is maybe truncated - please refine your search term to see more results.",
    "No users or groups found for {search}" : "No users or groups found for {search}",
    "No users found for {search}" : "No users found for {search}",
    "An error occurred (\"{message}\"). Please try again" : "An error occurred (\"{message}\"). Please try again",
    "An error occurred. Please try again" : "An error occurred. Please try again",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Share",
    "Name or email address..." : "Name or email address...",
    "Name or federated cloud ID..." : "Name or federated cloud ID...",
    "Name, federated cloud ID or email address..." : "Name, federated cloud ID or email address...",
    "Name..." : "Name...",
    "Error removing share" : "Error removing share",
    "SQLite will be used as database." : "SQLite will be used as database.",
    "For larger installations we recommend to choose a different database backend." : "For larger installations we recommend to choose a different database backend.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Especially when using the desktop client for file syncing, the use of SQLite is discouraged.",
    "Wrong password." : "Wrong password.",
    "New Password" : "New Password"
},
"nplurals=2; plural=(n != 1);");
